@@ -1,8 +1,8 @@
 from autoconv.state import State
 
 def raise_type_error(var,name,types):
-	if type(types) is not list: types = [types]
-	if var and type(var) not in types: raise TypeError(f"{name} must be {' or '.join([x.__name__ for x in types])}")
+	if type(types) is not tuple: types = (types,)
+	if var and not isinstance(var,types): raise TypeError(f"{name} must be {' or '.join([x.__name__ for x in types])}")
 
 class Conversation:
 
@@ -23,7 +23,7 @@ class Conversation:
 
 	def add_state(self,state):
 		'''Add state to the conversation'''
-		raise_type_error(state,'state',[State,list])
+		raise_type_error(state,'state',(State,list))
 		for s in state:
 			raise_type_error(s,'state',State)
 			if not self._state_already_exists(s): self.state_list.append(s)
@@ -35,15 +35,15 @@ class Conversation:
 		raise_type_error(routes,'routes',dict)
 		raise_type_error(default,'default',State)
 		raise_type_error(back,'back',State)
-		if state not in self.state_list: raise ValueError(f'{state} does not exists in this conversation.')
+		if state not in self.state_list: raise ValueError(f'{state} doesn\'t exist in this conversation.')
 		if routes:
 			for k,v in routes.items():
 				if (state.callback and k not in state.callback[0]) and k in (-1,'BACK'): raise ValueError(f'\'{k}\' it\'s not a possible value of {str(state)}.')
-				if v not in self.state_list: raise ValueError(f'{str(v)} does not exists in this conversation.')
+				if v not in self.state_list: raise ValueError(f'{str(v)} doesn\'t exist in this conversation.')
 			self.routes.update({state.name:routes})
 		if default:
-			if default not in self.state_list: raise ValueError(f'{str(default)} does not exists in this conversation.')
+			if default not in self.state_list: raise ValueError(f'{str(default)} doesn\'t exist in this conversation.')
 			s.update({-1:default}) if (s := self.routes.get(state.name)) else self.routes.update({state.name:{-1:default}})
 		if back:
-			if back not in self.state_list: raise ValueError(f'{str(default)} does not exists in this conversation.')
+			if back not in self.state_list: raise ValueError(f'{str(default)} doesn\'t exist in this conversation.')
 			s.update({'BACK':back}) if (s := self.routes.get(state.name)) else self.routes.update({state.name:{'BACK':back}})
\ No newline at end of file
